@@ -49,10 +49,13 @@ Examples:
 	$ smug print > ~/.config/smug/blog.yml
 `, version, FileUsage, WindowsUsage, AttachUsage, InsideCurrentSessionUsage, DebugUsage, DetachUsage)
 
-const defaultConfigFile = ".smug.yml"
+const (
+	defaultConfigFile = ".smug.yml"
+	logFile           = "smug.log"
+)
 
 func newLogger(path string) *log.Logger {
-	logFile, err := os.Create(filepath.Join(path, "smug.log"))
+	logFile, err := os.Create(filepath.Join(path, logFile))
 	if err != nil {
 		fmt.Fprintln(os.Stderr, err.Error())
 		os.Exit(1)
@@ -86,6 +89,18 @@ func getConfigs(options *Options, userConfigDir string) []string {
 }
 
 func main() {
+	userConfigDir := filepath.Join(ExpandPath("~/"), ".config/smug")
+
+	// Create config Directory
+	if err := os.MkdirAll(userConfigDir, 0o750); err != nil {
+		fmt.Fprintf(
+			os.Stderr,
+			"Cannot initialize config dir at ~/.config/smug : %q",
+			err.Error(),
+		)
+		os.Exit(1)
+	}
+
 	options, err := ParseOptions(os.Args[1:])
 	if errors.Is(err, ErrHelp) {
 		fmt.Fprint(os.Stdout, usage)
@@ -101,8 +116,6 @@ func main() {
 		os.Exit(1)
 	}
 
-	userConfigDir := filepath.Join(ExpandPath("~/"), ".config/smug")
-
 	var logger *log.Logger
 	if options.Debug {
 		logger = newLogger(userConfigDir)
@@ -113,10 +126,10 @@ func main() {
 	smug := Smug{tmux, commander}
 	context := CreateContext()
 
-	configs := getConfigs(options, userConfigDir)
-
 	switch options.Command {
 	case CommandStart:
+		configs := getConfigs(options, userConfigDir)
+
 		if len(options.Windows) == 0 {
 			fmt.Println("Starting a new session...")
 		} else {
@@ -140,6 +153,8 @@ func main() {
 			}
 		}
 	case CommandStop:
+		configs := getConfigs(options, userConfigDir)
+
 		if len(options.Windows) == 0 {
 			fmt.Println("Terminating session...")
 		} else {
@@ -160,12 +175,7 @@ func main() {
 			}
 		}
 	case CommandNew, CommandEdit:
-		if len(configs) == 0 {
-			fmt.Fprint(os.Stderr, "Cannot edit or create multiple configurations at once")
-			os.Exit(1)
-		}
-
-		err := EditConfig(configs[0])
+		err := EditConfig(filepath.Join(userConfigDir, options.Project+".yml"))
 		if err != nil {
 			fmt.Fprint(os.Stderr, err.Error())
 			os.Exit(1)
